==> huaweicloudsdkcae-3.1.40-py2.py3-none-any.whl: huaweicloudsdkcae/v1/model/list_environments_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListEnvironmentsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'api_version': 'str',
        'kind': 'str',
        'items': 'list[EnvironmentItem]'
    }

    attribute_map = {
        'api_version': 'api_version',
        'kind': 'Kind',
        'items': 'items'
    }

    def __init__(self, api_version=None, kind=None, items=None):
        """ListEnvironmentsResponse

        The model defined in huaweicloud sdk

        :param api_version: API版本。
        :type api_version: str
        :param kind: 资源种类。
        :type kind: str
        :param items: 环境信息列表。
        :type items: list[:class:`huaweicloudsdkcae.v1.EnvironmentItem`]
        """
        
        super(ListEnvironmentsResponse, self).__init__()

        self._api_version = None
        self._kind = None
        self._items = None
        self.discriminator = None

        if api_version is not None:
            self.api_version = api_version
        if kind is not None:
            self.kind = kind
        if items is not None:
            self.items = items

    @property
    def api_version(self):
        """Gets the api_version of this ListEnvironmentsResponse.

        API版本。

        :return: The api_version of this ListEnvironmentsResponse.
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this ListEnvironmentsResponse.

        API版本。

        :param api_version: The api_version of this ListEnvironmentsResponse.
        :type api_version: str
        """
        self._api_version = api_version

    @property
    def kind(self):
        """Gets the kind of this ListEnvironmentsResponse.

        资源种类。

        :return: The kind of this ListEnvironmentsResponse.
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this ListEnvironmentsResponse.

        资源种类。

        :param kind: The kind of this ListEnvironmentsResponse.
        :type kind: str
        """
        self._kind = kind

    @property
    def items(self):
        """Gets the items of this ListEnvironmentsResponse.

        环境信息列表。

        :return: The items of this ListEnvironmentsResponse.
        :rtype: list[:class:`huaweicloudsdkcae.v1.EnvironmentItem`]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ListEnvironmentsResponse.

        环境信息列表。

        :param items: The items of this ListEnvironmentsResponse.
        :type items: list[:class:`huaweicloudsdkcae.v1.EnvironmentItem`]
        """
        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListEnvironmentsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcae-3.1.57-py2.py3-none-any.whl: huaweicloudsdkcae/v1/model/list_environments_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListEnvironmentsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'api_version': 'str',
        'kind': 'str',
        'items': 'list[EnvironmentItem]'
    }

    attribute_map = {
        'api_version': 'api_version',
        'kind': 'Kind',
        'items': 'items'
    }

    def __init__(self, api_version=None, kind=None, items=None):
        """ListEnvironmentsResponse

        The model defined in huaweicloud sdk

        :param api_version: API版本，固定值“v1”，该值不可修改。
        :type api_version: str
        :param kind: API类型，固定值“Environment”，该值不可修改。
        :type kind: str
        :param items: 环境列表。
        :type items: list[:class:`huaweicloudsdkcae.v1.EnvironmentItem`]
        """
        
        super(ListEnvironmentsResponse, self).__init__()

        self._api_version = None
        self._kind = None
        self._items = None
        self.discriminator = None

        if api_version is not None:
            self.api_version = api_version
        if kind is not None:
            self.kind = kind
        if items is not None:
            self.items = items

    @property
    def api_version(self):
        """Gets the api_version of this ListEnvironmentsResponse.

        API版本，固定值“v1”，该值不可修改。

        :return: The api_version of this ListEnvironmentsResponse.
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this ListEnvironmentsResponse.

        API版本，固定值“v1”，该值不可修改。

        :param api_version: The api_version of this ListEnvironmentsResponse.
        :type api_version: str
        """
        self._api_version = api_version

    @property
    def kind(self):
        """Gets the kind of this ListEnvironmentsResponse.

        API类型，固定值“Environment”，该值不可修改。

        :return: The kind of this ListEnvironmentsResponse.
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this ListEnvironmentsResponse.

        API类型，固定值“Environment”，该值不可修改。

        :param kind: The kind of this ListEnvironmentsResponse.
        :type kind: str
        """
        self._kind = kind

    @property
    def items(self):
        """Gets the items of this ListEnvironmentsResponse.

        环境列表。

        :return: The items of this ListEnvironmentsResponse.
        :rtype: list[:class:`huaweicloudsdkcae.v1.EnvironmentItem`]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ListEnvironmentsResponse.

        环境列表。

        :param items: The items of this ListEnvironmentsResponse.
        :type items: list[:class:`huaweicloudsdkcae.v1.EnvironmentItem`]
        """
        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListEnvironmentsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
